==> aliyun-python-sdk-sts-3.0.2.tar.gz: aliyun-python-sdk-sts-3.0.2/aliyunsdksts/request/v20150401/AssumeRoleWithSAMLRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdksts.endpoint import endpoint_data

class AssumeRoleWithSAMLRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Sts', '2015-04-01', 'AssumeRoleWithSAML','sts')
		self.set_protocol_type('https')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_SAMLAssertion(self):
		return self.get_query_params().get('SAMLAssertion')

	def set_SAMLAssertion(self,SAMLAssertion):
		self.add_query_param('SAMLAssertion',SAMLAssertion)

	def get_RoleArn(self):
		return self.get_query_params().get('RoleArn')

	def set_RoleArn(self,RoleArn):
		self.add_query_param('RoleArn',RoleArn)

	def get_SAMLProviderArn(self):
		return self.get_query_params().get('SAMLProviderArn')

	def set_SAMLProviderArn(self,SAMLProviderArn):
		self.add_query_param('SAMLProviderArn',SAMLProviderArn)

	def get_DurationSeconds(self):
		return self.get_query_params().get('DurationSeconds')

	def set_DurationSeconds(self,DurationSeconds):
		self.add_query_param('DurationSeconds',DurationSeconds)

	def get_Policy(self):
		return self.get_query_params().get('Policy')

	def set_Policy(self,Policy):
		self.add_query_param('Policy',Policy)

==> aliyun-python-sdk-sts-3.1.0.tar.gz: aliyun-python-sdk-sts-3.1.0/aliyunsdksts/request/v20150401/AssumeRoleWithSAMLRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdksts.endpoint import endpoint_data

class AssumeRoleWithSAMLRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Sts', '2015-04-01', 'AssumeRoleWithSAML')
		self.set_protocol_type('https')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_SAMLAssertion(self):
		return self.get_query_params().get('SAMLAssertion')

	def set_SAMLAssertion(self,SAMLAssertion):
		self.add_query_param('SAMLAssertion',SAMLAssertion)

	def get_RoleArn(self):
		return self.get_query_params().get('RoleArn')

	def set_RoleArn(self,RoleArn):
		self.add_query_param('RoleArn',RoleArn)

	def get_SAMLProviderArn(self):
		return self.get_query_params().get('SAMLProviderArn')

	def set_SAMLProviderArn(self,SAMLProviderArn):
		self.add_query_param('SAMLProviderArn',SAMLProviderArn)

	def get_DurationSeconds(self):
		return self.get_query_params().get('DurationSeconds')

	def set_DurationSeconds(self,DurationSeconds):
		self.add_query_param('DurationSeconds',DurationSeconds)

	def get_Policy(self):
		return self.get_query_params().get('Policy')

	def set_Policy(self,Policy):
		self.add_query_param('Policy',Policy)
